@@ -37,11 +37,10 @@ update.fpar <- function (object, fp_p=NULL, fp_t=NULL, ...){
 }
 
 
-#' @importFrom purrr map
 #' @export
 #' @rdname fpar
 fortify_fpar <- function(x){
-  map(x$chunks, function(chk) {
+  lapply(x$chunks, function(chk) {
     if( !inherits(chk, "cot") ){
       chk <- ftext(text = format(chk), prop = x$fp_t )
     }
@@ -50,31 +49,28 @@ fortify_fpar <- function(x){
 }
 
 
-#' @importFrom purrr map map_lgl map_df
 #' @rdname fpar
 #' @export
 as.data.frame.fpar <- function( x, ...){
   chks <- fortify_fpar(x)
-  chks <- chks[map_lgl(chks, function(x) inherits(x, "ftext"))]
-  map_df(chks, function(x){
+  chks <- chks[sapply(chks, function(x) inherits(x, "ftext"))]
+  chks <- mapply(function(x){
     data.frame(value = x$value, size = x$pr$font.size,
            bold = x$pr$bold, italic = x$pr$italic,
            font.family = x$pr$font.family, stringsAsFactors = FALSE )
-  })
+  }, chks, SIMPLIFY = FALSE)
+  rbind.match.columns(chks)
 }
 
 #' @export
 #' @param type a string value ("pml", "wml" or "html").
 #' @param ... unused
-#' @importFrom purrr map_chr
 #' @rdname fpar
 format.fpar <- function( x, type = "pml", ...){
   if( type != "console" )
     par_style <- format(x$fp_p, type = type)
   chks <- fortify_fpar(x)
-  if( inherits(try(expr = map_chr(chks, format, type = type) ), "try-error"))
-    stop("unexpected error while formatting fpar in ", type, call. = FALSE)
-  chks <- map_chr(chks, format, type = type)
+  chks <- sapply(chks, format, type = type)
   chks <- paste0(chks, collapse = "")
   if( type == "pml" )
     out <- paste0("<a:p>", par_style, chks, "</a:p>")
