@@ -1,91 +1,3 @@
-# content_type -----
-content_type <- R6Class(
-  "content_type",
-  public = list(
-
-    initialize = function( x ) {
-
-      private$filename <- file.path(x$package_dir, "[Content_Types].xml")
-
-      doc <- read_xml(x = private$filename )
-      ns <- xml_ns(doc)
-
-      extension <- xml_find_all(doc, "//*[contains(local-name(), 'Default')]/@Extension", ns = ns)
-      extension <- xml_text( extension )
-      content_type <- xml_find_all(doc, "//*[contains(local-name(), 'Default')]/@ContentType", ns = ns)
-      content_type <- xml_text( content_type )
-      names(content_type) <- extension
-      private$default <- content_type
-
-      partname <- xml_find_all(doc, "//*[contains(local-name(), 'Override')]/@PartName", ns = ns)
-      partname <- xml_text(partname)
-      content_type <- xml_find_all(doc, "//*[contains(local-name(), 'Override')]/@ContentType", ns = ns)
-      content_type <- xml_text(content_type)
-      names(content_type) <- partname
-      private$override <- content_type
-
-    },
-
-    add_slide = function(partname){
-      partname <- basename(partname)
-      partname <- file.path("/ppt", "slides", partname )
-      content_type <- setNames("application/vnd.openxmlformats-officedocument.presentationml.slide+xml", partname )
-      override <- c( private$override, content_type )
-      private$override <- override
-      self
-    },
-    add_override = function(value){
-      override <- c( private$override, value )
-      private$override <- override
-      self
-    },
-    remove_slide = function(partname){
-      id <- which( basename(names(private$override)) %in% basename(partname) )
-      private$override <- private$override[-id]
-      self
-    },
-    add_ext = function( extension, type ){
-      if( !type %in% private$default && !extension %in% names(private$default) ){
-        content_type <- setNames(type, extension )
-        default <- c( private$default, content_type )
-        private$default <- default
-      }
-      self
-    },
-
-    save = function() {
-      self$add_ext(extension = "xlsx", type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
-      self$add_ext(extension = "jpeg", type = "image/jpeg")
-      self$add_ext(extension = "gif", type = "image/gif")
-      self$add_ext(extension = "png", type = "image/png")
-      self$add_ext(extension = "emf", type = "image/x-emf")
-      self$add_ext(extension = "jpg", type = "application/octet-stream")
-      attribs <- attr_chunk(c(xmlns = "http://schemas.openxmlformats.org/package/2006/content-types"))
-      out <- paste0("<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>",
-                    "\n<Types", attribs, ">")
-      if(length(private$default) > 0 ){
-        default <- sprintf("<Default Extension=\"%s\" ContentType=\"%s\"/>", names(private$default), private$default )
-        default <- paste0(default, collapse = "")
-        out <- paste0(out, default )
-      }
-      if(length(private$override) > 0 ){
-        override <- sprintf("<Override PartName=\"%s\" ContentType=\"%s\"/>", names(private$override), private$override )
-        override <- paste0(override, collapse = "")
-        out <- paste0(out, override )
-      }
-      out <- paste0(out, "</Types>" )
-      cat(out, file = private$filename)
-      self
-
-    }
-  ),
-  private = list(
-    filename = NULL,
-    default = NULL,
-    override = NULL
-  )
-)
-
 # presentation ------------------------------------------------------------
 
 presentation <- R6Class(
@@ -178,7 +90,7 @@ presentation <- R6Class(
       nodes <- xml_find_all(private$doc, "//p:sldIdLst/p:sldId")
       id <- as.integer( xml_attr(nodes, "id", ns = xml_ns(private$doc)) )
       rid <- xml_attr(nodes, "r:id", ns = xml_ns(private$doc))
-      tibble(id = id, rid = rid)
+      data.frame(id = id, rid = rid, stringsAsFactors = FALSE)
     }
   )
 )
@@ -235,7 +147,7 @@ slide_layout <- R6Class(
     get_metadata = function( ){
       rels <- self$rel_df()
       rels <- rels[basename( rels$type ) == "slideMaster", ]
-      tibble(name = self$name(), filename = self$file_name(), master_file = rels$target)
+      data.frame(stringsAsFactors = FALSE, name = self$name(), filename = self$file_name(), master_file = rels$target)
     },
     xfrm = function(){
       rels <- self$rel_df()
@@ -357,7 +269,7 @@ slide <- R6Class(
     get_metadata = function( ){
       rels <- self$rel_df()
       rels <- rels[basename( rels$type ) == "slideLayout", ]
-      tibble(name = self$name(), filename = self$file_name(), layout_file = rels$target)
+      data.frame(stringsAsFactors = FALSE, name = self$name(), filename = self$file_name(), layout_file = rels$target)
     }
 
   ),
@@ -379,7 +291,7 @@ dir_collection <- R6Class(
       private$package_dir <- x$package_dir
       dir_ <- file.path(private$package_dir, container$dir_name())
       filenames <- list.files(path = dir_, pattern = "\\.xml$", full.names = TRUE)
-      private$collection <- map( filenames, function(x, container){
+      private$collection <- lapply( filenames, function(x, container){
         container$clone()$feed(x)
       }, container = container)
       names(private$collection) <- basename(filenames)
@@ -390,13 +302,15 @@ dir_collection <- R6Class(
     },
 
     get_metadata = function(){
-      map_df(private$collection, function(x) x$get_metadata())
+      dat <- lapply(private$collection, function(x) x$get_metadata())
+      rbind.match.columns(dat)
     },
     names = function(){
-      map_chr(private$collection, function(x) x$name())
+      sapply(private$collection, function(x) x$name())
     },
     xfrm = function( ){
-      map_df(private$collection, function(x) x$xfrm() )
+      dat <- lapply(private$collection, function(x) x$xfrm() )
+      rbind.match.columns(dat)
     }
   ),
 
@@ -419,12 +333,13 @@ dir_master <- R6Class(
   public = list(
 
     get_metadata = function( ){
-      unames <- map_chr(private$collection, function(x) x$name())
-      ufnames <- map_chr(private$collection, function(x) x$file_name())
-      tibble(master_name = unames, filename = ufnames)
+      unames <- sapply(private$collection, function(x) x$name())
+      ufnames <- sapply(private$collection, function(x) x$file_name())
+      data.frame(stringsAsFactors = FALSE, master_name = unames, filename = ufnames)
     },
     get_color_scheme = function( ){
-      map_df(private$collection, function(x) x$colors())
+      dat <- lapply(private$collection, function(x) x$colors())
+      rbind.match.columns(dat)
     }
 
   )
@@ -432,7 +347,6 @@ dir_master <- R6Class(
 
 
 # dir_layout ---------------------------------------------------------
-#' @importFrom dplyr inner_join
 dir_layout <- R6Class(
   "dir_layout",
   inherit = dir_collection,
@@ -453,7 +367,7 @@ dir_layout <- R6Class(
       data_masters$master_file <- basename(data_masters$filename)
       data_masters$filename <- NULL
       data_layouts$master_file <- basename(data_layouts$master_file)
-      out <- inner_join(data_layouts, data_masters, by = "master_file")
+      out <- merge(data_layouts, data_masters, by = "master_file", all = FALSE)
       out$filename <- basename(out$filename)
       out
     },
@@ -471,7 +385,6 @@ dir_layout <- R6Class(
 
 
 # dir_slide ---------------------------------------------------------
-#' @importFrom dplyr between
 dir_slide <- R6Class(
   "dir_slide",
   inherit = dir_collection,
@@ -481,8 +394,8 @@ dir_slide <- R6Class(
       super$initialize(x, slide$new("ppt/slides"))
       private$slides_path <- file.path(x$package_dir, "ppt/slides")
       private$slide_layouts <- dir_layout$new( x )
-      private$collection <- map(private$collection, function(x, ref) x$set_xfrm(ref), ref = private$slide_layouts$get_xfrm_data() )
-      names(private$collection) <- map_chr(private$collection, function(x) x$name() )
+      private$collection <- lapply(private$collection, function(x, ref) x$set_xfrm(ref), ref = private$slide_layouts$get_xfrm_data() )
+      names(private$collection) <- sapply(private$collection, function(x) x$name() )
     },
 
     update = function( ){
@@ -493,11 +406,11 @@ dir_slide <- R6Class(
       sl_id <- as.integer( gsub( "(slide)([0-9]+)(\\.xml)$", "\\2", basename(filenames) ) )
       filenames <- filenames[order(sl_id)]
 
-      private$collection <- map( filenames, function(x, container){
+      private$collection <- lapply( filenames, function(x, container){
         container$clone()$feed(x)$fortify_id()
       }, container = slide$new("ppt/slides"))
       private$slides_path <- file.path(private$package_dir, "ppt/slides")
-      private$collection <- map(private$collection, function(x, ref) x$set_xfrm(ref), ref = private$slide_layouts$get_xfrm_data() )
+      private$collection <- lapply(private$collection, function(x, ref) x$set_xfrm(ref), ref = private$slide_layouts$get_xfrm_data() )
       names(private$collection) <- basename(filenames)
       self
     },
@@ -519,7 +432,7 @@ dir_slide <- R6Class(
       slide_obj$remove()
     },
     get_xfrm = function( ){
-      map(private$collection, function(x) x$get_xfrm() )
+      lapply(private$collection, function(x) x$get_xfrm() )
     },
 
 
@@ -568,7 +481,7 @@ dir_slide <- R6Class(
       slidename
     },
     layout_files = function(){
-      map_chr(private$collection, function(x) x$layout_name())
+      sapply(private$collection, function(x) x$layout_name())
     }
   ),
   private = list(
