@@ -6,7 +6,9 @@
 #' @param style text style, a \code{\link{fp_text}} object
 #' @param pos where to add the new element relative to the cursor,
 #' "after" or "before".
-#' @param href hyperlink
+#' @param href hyperlink to reach when clicking the text
+#' @param slide_index slide index to reach when clicking the text.
+#' It will be ignored if \code{href} is not NULL.
 #' @examples
 #' library(magrittr)
 #' fileout <- tempfile(fileext = ".pptx")
@@ -23,9 +25,25 @@
 #'   ph_add_text(str = "Level 2")
 #'
 #' print(my_pres, target = fileout)
+#'
+#'
+#' fileout <- tempfile(fileext = ".pptx")
+#' doc <- read_pptx() %>%
+#'   add_slide(layout = "Title and Content", master = "Office Theme") %>%
+#'   ph_with_text(type = "title", str = "Un titre 1") %>%
+#'   add_slide(layout = "Title and Content", master = "Office Theme") %>%
+#'   ph_with_text(type = "title", str = "Un titre 2") %>%
+#'   on_slide(1) %>%
+#'   ph_empty(type = "body") %>%
+#'   ph_add_par(type = "body", level = 2) %>%
+#'   ph_add_text(str = "Jump here to slide 2!", type = "body",
+#'   slide_index = 2)
+#'
+#' print(doc, target = fileout)
 #' @importFrom xml2 xml_child xml_children xml_add_child
 ph_add_text <- function( x, str, type = NULL, id_chr = NULL,
-  style = fp_text(font.size = 0), pos = "after", href = NULL ){
+  style = fp_text(font.size = 0), pos = "after",
+  href = NULL, slide_index = NULL ){
 
   slide <- x$slide$get_slide(x$cursor)
   shape_id <- get_shape_id(x, type = type, id_chr = id_chr )
@@ -51,6 +69,16 @@ ph_add_text <- function( x, str, type = NULL, id_chr = NULL,
     str_ <- "<a:hlinkClick xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" r:id=\"%s\"/>"
     str_ <- sprintf(str_, id)
     xml_add_child(apr, as_xml_document(str_) )
+  } else if( !is.null(slide_index)){
+    slide_name <- x$slide$names()[slide_index]
+    slide$reference_slide(slide_name)
+    rel_df <- slide$rel_df()
+    id <- rel_df[rel_df$target == slide_name, "id" ]
+    # add hlinkClick
+    apr <- xml_child(new_node, "a:rPr")
+    str_ <- "<a:hlinkClick xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" xmlns:r=\"http://schemas.openxmlformats.org/officeDocument/2006/relationships\" r:id=\"%s\" action=\"ppaction://hlinksldjump\"/>"
+    str_ <- sprintf(str_, id)
+    xml_add_child(apr, as_xml_document(str_) )
   }
 
 
