@@ -63,8 +63,18 @@ test_that("body_add_toc", {
 
 })
 
-test_that("image add ", {
-  img.file <- file.path( Sys.getenv("R_HOME"), "doc", "html", "logo.jpg" )
+test_that("body_add_img", {
+
+  img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
+  x <- read_docx() %>%
+    body_add_img(img.file, width=2.5, height=1.3)
+
+  node <- x$doc_obj$get_at_cursor()
+  getncheck(node, "w:r/w:drawing")
+})
+
+test_that("slip_in_img", {
+  img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
   x <- read_docx() %>%
     body_add_par("") %>%
     slip_in_img(src = img.file, style = "strong", width = .3, height = .3)
@@ -74,6 +84,9 @@ test_that("image add ", {
 })
 
 test_that("ggplot add", {
+  testthat::skip_if_not(requireNamespace("ggplot2", quietly = TRUE))
+  library("ggplot2")
+
   gg_plot <- ggplot(data = iris ) +
     geom_point(mapping = aes(Sepal.Length, Petal.Length))
   x <- read_docx() %>%
